//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <WScom.h>
#include <WSDappDev.h>
#include <WSCbaseList.h>

#ifdef MSW
WS_WINMAIN
#endif

char* mou[] = { " 0   132        0          black      white", NULL };

void _mouse_init_(){
  WSGFloadMouseCursorData(mou);
}

char* fon[] = {
"14 * 0 0",
"16 * 0 0",
"24 * 0 0",
"24 * 0 0",
"24 * 0 0",
"24 * 0 0",
"24 * 0 0",
"24 * 0 0",
NULL};

void _font_init_(){
  WSGFloadFontData(fon);
}
class _init_app_class_{
  public: _init_app_class_(){
    WSGFdeviceInitialize();
    WSGIappDev()->setInitHandler(_font_init_);
    WSGIappDev()->setInitHandler(_mouse_init_);
    WSDappDev* app = WSGIappDev();
    app->setInstanceName("title");
  };
};
static _init_app_class_ _execute_app_class_;

extern WSDLEX void _create_pic_newpic000();
class _init_picture_class_0{
 public: _init_picture_class_0(){
  WSGIappDev()->setInitHandler(_create_pic_newpic000);
 };
};
static _init_picture_class_0 _execute_initialize_0;

